==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_maintenance/com/clustercontrol/maintenance/factory/AddMaintenance.java <==
/*
 
Copyright (C) 2007 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.maintenance.factory;

import java.sql.Timestamp;
import java.util.Date;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import com.clustercontrol.HinemosUnknownException;
import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.maintenance.bean.MaintenanceInfoDataImp;
import com.clustercontrol.maintenance.ejb.entity.MaintenanceInfoUtil;
import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;

/**
 * メンテナンス情報を登録するためのクラスです。
 * 
 * @version 3.0.0
 * @since 2.2.0
 *
 */
public class AddMaintenance {
	
	public boolean addMaintenance(MaintenanceInfoDataImp data, String name) throws CreateException, NamingException, HinemosUnknownException {
		
		AccessLock.lock(AccessLock.MAINTENANCE);
		
		//エンティティBeanをつくる
		MaintenanceInfoUtil.getLocalHome().create(
				data.getMaintenance_id(),
				data.getDescription(),
				data.getType_id(),
				data.getKeep_id(),
				data.getCalendar_id(),
				
//				data.getSchedule_date(),
				null,
				
				data.getNotifyGroupId(),
				data.getApplication(),
				data.getValid_flg(),
				name,
				new Timestamp(new Date().getTime()),
				name,
				new Timestamp(new Date().getTime()));
		
		
		if(data.getNotifyId() != null){
			
			NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
			
			nc.addNotifyRelation(data.getNotifyId());
		}
		
		
		return true;
		
	}
	
}

==> hinemos_src-4.0.0.tar.gz: HinemosManager/src_maintenance/com/clustercontrol/maintenance/factory/AddMaintenance.java <==
/*

Copyright (C) 2007 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.maintenance.factory;

import java.sql.Timestamp;
import java.util.Date;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import com.clustercontrol.fault.HinemosUnknown;
import com.clustercontrol.maintenance.bean.MaintenanceInfo;
import com.clustercontrol.maintenance.ejb.entity.MaintenanceInfoUtil;
import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;

/**
 * メンテナンス情報を登録するためのクラスです。
 * 
 * @version 4.0.0
 * @since 2.2.0
 *
 */
public class AddMaintenance {

	public boolean addMaintenance(MaintenanceInfo data, String name) throws CreateException, NamingException, HinemosUnknown {

		//エンティティBeanをつくる
		MaintenanceInfoUtil.getLocalHome().create(
				data.getMaintenanceId(),
				data.getDescription(),
				data.getTypeId(),
				data.getDataRetentionPeriod(),
				data.getCalendarId(),
				data.getSchedule().getType(),
				data.getSchedule().getMonth(),
				data.getSchedule().getDay(),
				data.getSchedule().getWeek(),
				data.getSchedule().getHour(),
				data.getSchedule().getMinute(),
				data.getNotifyGroupId(),
				data.getApplication(),
				data.getValidFlg(),
				name,
				new Timestamp(new Date().getTime()),
				name,
				new Timestamp(new Date().getTime()));

		if(data.getNotifyId() != null){

			NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();

			nc.addNotifyRelation(data.getNotifyId());
		}


		return true;

	}

}
